@@ -182,17 +182,24 @@ def addUserToBlackList(rawJwt=None, apiInstance=None) :
 
 @Function
 def getJwtMannager(appInstance, jwtSecret, algorithm=None, headerName=None, headerType=None):
-    if SettingHelper.activeEnvironmentIsLocal():
-        log.setting(getJwtMannager, f'JWT session secret: {jwtSecret}')
     if not jwtSecret:
         log.warning(getJwtMannager, f'Not possible to instanciate sessionManager{c.DOT_SPACE_CAUSE}Missing jwt secret at {ConfigurationKeyConstant.API_SESSION_SECRET}')
     else:
-        return JwtManager(
+        jwtManager = JwtManager(
             jwtSecret,
             ConverterStatic.getValueOrDefault(algorithm, JwtConstant.DEFAULT_JWT_SESSION_ALGORITHM),
             ConverterStatic.getValueOrDefault(headerName, JwtConstant.DEFAULT_JWT_SESSION_HEADER_NAME),
             ConverterStatic.getValueOrDefault(headerType, JwtConstant.DEFAULT_JWT_SESSION_HEADER_TYPE)
         )
+        if SettingHelper.activeEnvironmentIsLocal():
+            info = {
+                'secret': jwtManager.secret,
+                'algorithm': jwtManager.algorithm,
+                'headerName': jwtManager.headerName,
+                'headerType': jwtManager.headerType
+            }
+            log.setting(getJwtMannager, f'''JWT session: {info}''')
+        return jwtManager
 
 @Function
 def addJwt(jwtInstance) :
